<h1 align = "center">:rocket: Metrics :facepunch:</h1>

---
## [推荐系统常用指标][15]
## [sklearn.metrics][11]

- [自定义评估函数][12]
---
## [ml_metrics][0]

|**评估指标**|**公式**|
|:--|:--:|
|[Kolmogorov-Smirnov (KS)][14]| ![][13]
|AbsoluteError (AE)|
|Average Precision at K (APK, AP@K)|
|[Area Under the ROC (AUC)][2] | ![AUC][1]
|Classification Error (CE)| 
|F1 Score (F1)|
|Gini|
|Levenshtein|
|Log Loss (LL)| ![logloss][3]
|Mean Log Loss (LogLoss)|
|Mean Absolute Error (MAE)|
|Mean Average Precision at K (MAPK, MAP@K)|
|Mean Quadratic Weighted Kappa|
|Mean Squared Error (MSE)|
|Mean Squared Log Error (MSLE)|
|Normalized Gini|
|Quadratic Weighted Kappa|
|Relative Absolute Error (RAE)|
|Root Mean Squared Error (RMSE)|
|Relative Squared Error (RSE)|
|Root Relative Squared Error (RRSE)|
|Root Mean Squared Log Error (RMSLE)|
|Squared Error (SE)|
|Squared Log Error (SLE)|

---

 [0]: https://github.com/benhamner/Metrics/tree/master/Python
 [1]: http://img.blog.csdn.net/20150924153157802
 [2]: http://third.datacastle.cn/pkbigdata/master.other.img/7372d308-8d38-4e45-8ab7-ffab7763096a.png
 [3]: https://github.com/Jie-Yuan/DataMining/raw/master/7_Metrics/Pictures/11.png
 [11]: http://scikit-learn.org/stable/modules/model_evaluation.html#common-cases-predefined-values
 [12]: http://www.cnblogs.com/harvey888/p/6964741.html
 [13]: https://img-blog.csdn.net/20171012171557401?watermark/2/text/aHR0cDovL2Jsb2cuY3Nkbi5uZXQvdTAxMzQyMTYyOQ==/font/5a6L5L2T/fontsize/400/fill/I0JBQkFCMA==/dissolve/70/gravity/SouthEast
 [14]: https://www.cnblogs.com/bergus/p/shu-ju-wa-jue-shu-yu-jie-xi.html
 [15]: https://mp.weixin.qq.com/s?__biz=MzI1MzY0MzE4Mg==&mid=2247483981&idx=1&sn=f347a44a7b41693bc923de91d159dbf3&chksm=e9d0128cdea79b9a5628e932f614a681867d76307a90a0db67e8195c0b855e6a5160528a72d0&scene=0#rd
